clear

warning off MATLAB:divideByZero;
warning off MATLAB:singularMatrix;
warning off MATLAB:rankDeficientMatrix;

format compact;
format short g;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;
%%%%%%%%%%%%%%%%%%%%%%% MARGINAL EFFECTS FOR PANEL DATA DYNAMIC DISCRETE CHOICE MODELS %%%%%%%%%%%%%%%%%%%%%%%%;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;
% APPLICATION: WOMEN LABOR FORCE PARTICIPATION;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;
% dstar_{it} = x_{it}' \beta + \alpha_2{i} - \epsilon2_{it};
% d_{it} = 1{dstar_{it} > 0};
% Variables;
%   1.- d = dummy for welfare participation (=1 for participants);
%   2.- Regressors ;
%       ii) Specification 3 ;
%           +.- kids1: # of kids < 2;
%           +.- kids2: # of kids 3-6;
%           +.- kids3: # of kids >6;
%           +.- lincome: log of husband earnings;
%           +.- age;
%           +.- age^2;
%       iii) Specification 2 ;
%           +.- Time dummies (8) (omitted for first period);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;
% VALUES OF THE PARAMETERS;

B = 1;
T = 9;
specification = 3; % chooses specification;

% LOADING DATASET;

load('z:\marginal_effects\applications\LFP3\data\lfp_psid_fs.txt','-ascii');
load('z:\marginal_effects\applications\LFP3\data\lfp_psid.txt','-ascii');
N = size(lfp_psid_fs,1)/T;
Np = size(lfp_psid,1)/T;
%Np = 1200;

clog = sqrt(3) / pi;
cprob = pi / sqrt(3);
options = optimset('GradObj','on');


%options = optimset('GradObj','on');

% ESTIMATION;

tic,
for i = 1:B,

    disp(i);

% CONSTRUCTING MATRICES OF DATA;

    if specification == 1,
        p2 = 1;
        x2 = [lfp_psid(1:Np*T,4)];
        x2_fs = [lfp_psid_fs(:,4)];
    elseif specification == 2,
        p2 = 14;
        x2 = [lfp_psid(1:Np*T,5:18)];
        x2_fs = [lfp_psid_fs(:,5:18)];
    else,
        p2 = 6;
        x2 = [lfp_psid(1:Np*T,[5:10])];
        x2_fs = [lfp_psid_fs(:,[5:10])];
    end;

    d = lfp_psid(1:Np*T,3);
    d_fs = lfp_psid_fs(1:N*T,3);
    
    clear lfp_psid_fs;
  
    x2bar_fs(:,i) = mean(x2_fs)';
    s2x2bar_fs = cov(x2_fs,1) / size(x2_fs,1);
    
%    clear x2_fs;
    clear lfp_psid;


% MATRICES FOR FIXED EFFECTS;
D = kron([1:N]',ones(T,1));
FE = sparse(dummyvar(D));
X2 = [x2_fs,FE];

% LPM: FIXED EFFECTS LINEAR PROBABILITY MODEL (FULL SAMPLE);
    delta = X2\d_fs;
       
    H_lpm = vc_olsen(d_fs,X2,delta);
    betahatlpm(:,i) = delta(1:p2,1);
    s2hat_lpm(:,i) = diag(H_lpm(1:p2,1:p2));
    
    mulpm = X2*delta;
       
    meffhatlpm_fs(:,i) = betahatlpm(:,i);
    ameffhatlpm_fs(:,i) = betahatlpm(:,i);
    s2hat_meff_lpm_fs(:,i) = s2hat_lpm(:,i);
    s2hat_ameff_lpm_fs(:,i) = s2hat_lpm(:,i);




% MATRICES FOR FIXED EFFECTS;
D = kron([1:Np]',ones(T,1));
FE = sparse(dummyvar(D));


    
% ELIMINATING INDIVIDUALS WITH ALL 1's OR 0's;
    x2p = x2;
    FEp = FE;
    Dp = D;

    X2 = [x2p,FEp];
    

    nobs1(i) = T*Np;
%    init = X2\d;

%%%%%%%%%%%%%%%%%;
% FIRST STAGE;
%%%%%%%%%%%%%%%%%;

% OLSEN ESTIMATOR: FIXED EFFECTS LINEAR PROBABILITY MODEL;
    delta = X2\d;
       
    H_olsen = vc_olsen(d,X2,delta);
    betahatolsen(:,i) = delta(1:p2,1);
    s2hat_olsen(:,i) = diag(H_olsen(1:p2,1:p2));
    
    muolsen = X2*delta;
       
    meffhatolsen_fs(:,i) = (Np/N)*betahatolsen(:,i);
    ameffhatolsen_fs(:,i) = (Np/N)*betahatolsen(:,i);
    s2hat_meff_olsen_fs(:,i) = ((Np/N)^2)*s2hat_olsen(:,i);
    s2hat_ameff_olsen_fs(:,i) = ((Np/N)^2)*s2hat_olsen(:,i);

% MLE PROBIT;
    deltahat = glmfit1(X2,[d ones(size(d,1),1)],'binomial','probit','off',[ ],[ ] ,'off');
    Hhat_mle = vc_probit(d,X2,deltahat);
    s2hat_mle(:,i) = diag(Hhat_mle(1:p2,1:p2));
    bhat1(:,i) = deltahat(1:p2,1);    
    
    muhat = X2*deltahat;

    
    meffhat_fs(:,i) = bhat1(:,i) * sum(normpdf(x2bar_fs(:,i)' * bhat1(:,i) + deltahat((p2+1):size(deltahat,1),1)))/N;
    ameffhat_fs(:,i) = bhat1(:,i) * sum(normpdf(X2*deltahat))/(N*T);
    Hhat_meff_mle_fs = vc_meff_probit(d, x2bar_fs(:,i), deltahat, Hhat_mle, s2x2bar_fs, N, p2);
    s2hat_meff_mle_fs(:,i) = diag(Hhat_meff_mle_fs);
    Hhat_ameff_mle_fs = vc_ameff_probit(d, X2, deltahat, Hhat_mle, p2, N*T);
    s2hat_ameff_mle_fs(:,i) = diag(Hhat_ameff_mle_fs);
    
    
    
% ANALYTICAL BC MLE PROBIT;    
    BIAS1(:,i) = bias_beta_probit_mle(d,X2,deltahat,Np,Dp);
    bhatbc1(:,i) = bhat1(:,i) - (1/T)*BIAS1(:,i);
    b1 = bhatbc1(:,i);
    delhat1 = glmfit1(X2(:,(p2+1):size(X2,2)),[d ones(size(d,1),1)],'binomial','probit','off',X2(:,1:p2)*b1,[ ] ,'off');
    deltahat1 = [bhatbc1(:,i);delhat1];

    Hhat_bc1 = vc_probit(d,X2,[b1;delhat1]);
    s2hat_bc1(:,i) = diag(Hhat_bc1(1:p2,1:p2));

    biasalphahatbc1 = bias_alpha_probit_mle(d,X2,[bhatbc1(:,i);delhat1],Dp);
    sigma2alphahatbc1 = sigma2_alpha_probit_mle(d,X2,[bhatbc1(:,i);delhat1],Dp);
    phialphahatbc1 = phi_alpha_probit_mle(d,X2,[bhatbc1(:,i);delhat1],Dp);
    muhatbc1 = x2p*bhatbc1(:,i) + kron(delhat1,ones(T,1));
    
    bias_meff_bc1_fs = bias_meff_probit(x2bar_fs(:,i), deltahat1, biasalphahatbc1, sigma2alphahatbc1,p2,Dp,N);  
    meffhatbc1_fs(:,i) = bhatbc1(:,i) * sum(normpdf(x2bar_fs(:,i)' * bhatbc1(:,i) + deltahat1((p2+1):size(deltahat1,1),1)))/N - bias_meff_bc1_fs/T;
    bias_ameff_bc1_fs = bias_ameff_probit(muhatbc1, deltahat1, biasalphahatbc1, sigma2alphahatbc1, phialphahatbc1, p2 ,Dp, N*T);
    ameffhatbc1_fs(:,i) = bhatbc1(:,i) * sum(normpdf(X2*deltahat1))/(N*T) - bias_ameff_bc1_fs/T;
    Hhat_meff_bc1_fs = vc_meff_probit(d, x2bar_fs(:,i), deltahat1, Hhat_bc1, s2x2bar_fs, N, p2);
    s2hat_meff_bc1_fs(:,i) = diag(Hhat_meff_bc1_fs);
    Hhat_ameff_bc1_fs = vc_ameff_probit(d, X2, deltahat1, Hhat_bc1, p2, N*T);
    s2hat_ameff_bc1_fs(:,i) = diag(Hhat_ameff_bc1_fs);
    
% ANALYTICAL-M BC MLE PROBIT;    
    BIAS2(:,i) = bias_beta_probit(d,X2,deltahat,Np,Dp);
%    BIAS2_2(:,i) = bias_beta(d,X2,delta,Np,Dp);
    bhatbc2(:,i) = bhat1(:,i) - (1/T)*BIAS2(:,i);
    b2 = bhatbc2(:,i);
    delhat2 = glmfit1(X2(:,(p2+1):size(X2,2)),[d ones(size(d,1),1)],'binomial','probit','off',X2(:,1:p2)*b2,[ ] ,'off');
    deltahat2 = [bhatbc2(:,i);delhat2];

    Hhat_bc2 = vc_probit(d,X2,[b2;delhat2]);
    s2hat_bc2(:,i) = diag(Hhat_bc2(1:p2,1:p2));

    biasalphahatbc2 = bias_alpha_probit(d,X2,[bhatbc2(:,i);delhat2],Dp);
    sigma2alphahatbc2 = sigma2_alpha_probit(d,X2,[bhatbc2(:,i);delhat2],Dp);
    phialphahatbc2 = phi_alpha_probit(d,X2,[bhatbc2(:,i);delhat2],Dp);
    muhatbc2 = x2p*bhatbc2(:,i) + kron(delhat2,ones(T,1));
    
    bias_meff_bc2_fs = bias_meff_probit(x2bar_fs(:,i), deltahat2, biasalphahatbc2, sigma2alphahatbc2,p2,Dp,N);  
    meffhatbc2_fs(:,i) = bhatbc2(:,i) * sum(normpdf(x2bar_fs(:,i)' * bhatbc2(:,i) + deltahat2((p2+1):size(deltahat2,1),1)))/N - bias_meff_bc2_fs/T;
    bias_ameff_bc2_fs = bias_ameff_probit(muhatbc2, deltahat2, biasalphahatbc2, sigma2alphahatbc2, phialphahatbc2, p2 ,Dp, N*T);
    ameffhatbc2_fs(:,i) = bhatbc2(:,i) * sum(normpdf(X2*deltahat2))/(N*T) - bias_ameff_bc2_fs/T;
    Hhat_meff_bc2_fs = vc_meff_probit(d, x2bar_fs(:,i), deltahat2, Hhat_bc2, s2x2bar_fs, N, p2);
    s2hat_meff_bc2_fs(:,i) = diag(Hhat_meff_bc2_fs);
    Hhat_ameff_bc2_fs = vc_ameff_probit(d, X2, deltahat2, Hhat_bc2, p2, N*T);
    s2hat_ameff_bc2_fs(:,i) = diag(Hhat_ameff_bc2_fs);

    
% ANALYTICAL 2 BC MLE PROBIT;    
    BIAS3(:,i) = bias_beta_probit_mle2(d,X2,deltahat,Np,Dp);
    bhatbc3(:,i) = bhat1(:,i) - (1/T)*BIAS3(:,i);
    b3 = bhatbc3(:,i);
    delhat3 = glmfit1(X2(:,(p2+1):size(X2,2)),[d ones(size(d,1),1)],'binomial','probit','off',X2(:,1:p2)*b3,[ ] ,'off');
    deltahat3 = [bhatbc3(:,i);delhat3];

    Hhat_bc3 = vc_probit(d,X2,[b3;delhat3]);
    s2hat_bc3(:,i) = diag(Hhat_bc3(1:p2,1:p2));

    biasalphahatbc3 = bias_alpha_probit_mle2(d,X2,[bhatbc3(:,i);delhat3],Dp);
    sigma2alphahatbc3 = sigma2_alpha_probit_mle2(d,X2,[bhatbc3(:,i);delhat3],Dp);
    phialphahatbc3 = phi_alpha_probit_mle2(d,X2,[bhatbc3(:,i);delhat3],Dp);
    muhatbc3 = x2p*bhatbc3(:,i) + kron(delhat3,ones(T,1));
    
   
    bias_meff_bc3_fs = bias_meff_probit(x2bar_fs(:,i), deltahat3, biasalphahatbc3, sigma2alphahatbc3,p2,Dp,N);  
    meffhatbc3_fs(:,i) = bhatbc3(:,i) * sum(normpdf(x2bar_fs(:,i)' * bhatbc3(:,i) + deltahat3((p2+1):size(deltahat3,1),1)))/N - bias_meff_bc3_fs/T;
    bias_ameff_bc3_fs = bias_ameff_probit(muhatbc3, deltahat3, biasalphahatbc3, sigma2alphahatbc3, phialphahatbc3, p2 ,Dp, N*T);
    ameffhatbc3_fs(:,i) = bhatbc3(:,i) * sum(normpdf(X2*deltahat3))/(N*T) - bias_ameff_bc3_fs/T;
    Hhat_meff_bc3_fs = vc_meff_probit(d, x2bar_fs(:,i), deltahat3, Hhat_bc3, s2x2bar_fs, N, p2);
    s2hat_meff_bc3_fs(:,i) = diag(Hhat_meff_bc3_fs);
    Hhat_ameff_bc3_fs = vc_ameff_probit(d, X2, deltahat3, Hhat_bc3, p2, N*T);
    s2hat_ameff_bc3_fs(:,i) = diag(Hhat_ameff_bc3_fs);

% ANALYTICAL 3 BC MLE PROBIT;    
    BIAS4(:,i) = bias_beta_probit_mle3(d,X2,deltahat,Np,Dp);
    bhatbc4(:,i) = bhat1(:,i) - (1/T)*BIAS4(:,i);
    b4 = bhatbc4(:,i);
    delhat4 = glmfit1(X2(:,(p2+1):size(X2,2)),[d ones(size(d,1),1)],'binomial','probit','off',X2(:,1:p2)*b4,[ ] ,'off');
    deltahat4 = [bhatbc4(:,i);delhat4];

    Hhat_bc4 = vc_probit(d,X2,[b4;delhat4]);
    s2hat_bc4(:,i) = diag(Hhat_bc4(1:p2,1:p2));

    biasalphahatbc4 = bias_alpha_probit_mle2(d,X2,[bhatbc4(:,i);delhat4],Dp);
    sigma2alphahatbc4 = sigma2_alpha_probit_mle2(d,X2,[bhatbc4(:,i);delhat4],Dp);
    phialphahatbc4 = phi_alpha_probit_mle2(d,X2,[bhatbc4(:,i);delhat4],Dp);
    muhatbc4 = x2p*bhatbc4(:,i) + kron(delhat4,ones(T,1));
    
        
    bias_meff_bc4_fs = bias_meff_probit(x2bar_fs(:,i), deltahat4, biasalphahatbc4, sigma2alphahatbc4,p2,Dp,N);  
    meffhatbc4_fs(:,i) = bhatbc4(:,i) * sum(normpdf(x2bar_fs(:,i)' * bhatbc4(:,i) + deltahat4((p2+1):size(deltahat4,1),1)))/N - bias_meff_bc4_fs/T;
    bias_ameff_bc4_fs = bias_ameff_probit(muhatbc4, deltahat4, biasalphahatbc4, sigma2alphahatbc4, phialphahatbc4, p2 ,Dp, N*T);
    ameffhatbc4_fs(:,i) = bhatbc4(:,i) * sum(normpdf(X2*deltahat4))/(N*T) - bias_ameff_bc4_fs/T;
    Hhat_meff_bc4_fs = vc_meff_probit(d, x2bar_fs(:,i), deltahat4, Hhat_bc4, s2x2bar_fs, N, p2);
    s2hat_meff_bc4_fs(:,i) = diag(Hhat_meff_bc4_fs);
    Hhat_ameff_bc4_fs = vc_ameff_probit(d, X2, deltahat4, Hhat_bc4, p2, N*T);
    s2hat_ameff_bc4_fs(:,i) = diag(Hhat_ameff_bc4_fs);

% MLE LOGIT;
    deltatilde = glmfit1(X2,[d ones(size(d,1),1)],'binomial','logit','off',[ ],[ ] ,'off');
    Htilde_mle = vc_logit(d,X2,deltatilde);
    s2tilde_mle(:,i) = diag(Htilde_mle(1:p2,1:p2));
    btilde1(:,i) = deltatilde(1:p2,1);    
    
    mutilde = X2*deltatilde;

    mefftilde_fs(:,i) = btilde1(:,i) * sum(logpdf(x2bar_fs(:,i)' * btilde1(:,i) + deltatilde((p2+1):size(deltatilde,1),1)))/N;
    amefftilde_fs(:,i) = btilde1(:,i) * sum(logpdf(X2*deltatilde))/(N*T);
    Htilde_meff_mle_fs = vc_meff_logit(d, x2bar_fs(:,i), deltatilde, Htilde_mle, s2x2bar_fs, N, p2);
    s2tilde_meff_mle_fs(:,i) = diag(Htilde_meff_mle_fs);
    Htilde_ameff_mle_fs = vc_ameff_logit(d, X2, deltatilde, Htilde_mle, p2, N*T);
    s2tilde_ameff_mle_fs(:,i) = diag(Htilde_ameff_mle_fs);

% ANALYTICAL BC MLE LOGIT;    
    BIAS1(:,i) = bias_beta_logit_mle(d,X2,deltatilde,Np,Dp);
    btildebc1(:,i) = btilde1(:,i) - (1/T)*BIAS1(:,i);
    b1 = btildebc1(:,i);
    deltilde1 = glmfit1(X2(:,(p2+1):size(X2,2)),[d ones(size(d,1),1)],'binomial','logit','off',X2(:,1:p2)*b1,[ ] ,'off');
    deltatilde1 = [btildebc1(:,i);deltilde1];

    Htilde_bc1 = vc_logit(d,X2,[b1;deltilde1]);
    s2tilde_bc1(:,i) = diag(Htilde_bc1(1:p2,1:p2));

    biasalphatildebc1 = bias_alpha_logit_mle(d,X2,[btildebc1(:,i);deltilde1],Dp);
    sigma2alphatildebc1 = sigma2_alpha_logit_mle(d,X2,[btildebc1(:,i);deltilde1],Dp);
    phialphatildebc1 = phi_alpha_logit_mle(d,X2,[btildebc1(:,i);deltilde1],Dp);
    mutildebc1 = x2p*btildebc1(:,i) + kron(deltilde1,ones(T,1));
    
    bias_meff_bc1_fs = bias_meff_logit(x2bar_fs(:,i), deltatilde1, biasalphatildebc1, sigma2alphatildebc1,p2,Dp,N);  
    mefftildebc1_fs(:,i) = btildebc1(:,i) * sum(logpdf(x2bar_fs(:,i)' * btildebc1(:,i) + deltatilde1((p2+1):size(deltatilde1,1),1)))/N - bias_meff_bc1_fs/T;
    bias_ameff_bc1_fs = bias_ameff_logit(mutildebc1, deltatilde1, biasalphatildebc1, sigma2alphatildebc1, phialphatildebc1, p2 ,Dp, N*T);
    amefftildebc1_fs(:,i) = btildebc1(:,i) * sum(logpdf(X2*deltatilde1))/(N*T) - bias_ameff_bc1_fs/T;
    Htilde_meff_bc1_fs = vc_meff_logit(d, x2bar_fs(:,i), deltatilde1, Htilde_bc1, s2x2bar_fs, N, p2);
    s2tilde_meff_bc1_fs(:,i) = diag(Htilde_meff_bc1_fs);
    Htilde_ameff_bc1_fs = vc_ameff_logit(d, X2, deltatilde1, Htilde_bc1, p2, N*T);
    s2tilde_ameff_bc1_fs(:,i) = diag(Htilde_ameff_bc1_fs);
    
    
% ANALYTICAL-M BC MLE LOGIT;    
    BIAS2(:,i) = bias_beta_logit(d,X2,deltatilde,Np,Dp);
%    BIAS2_2(:,i) = bias_beta(d,X2,delta,Np,Dp);
    btildebc2(:,i) = btilde1(:,i) - (1/T)*BIAS2(:,i);
    b2 = btildebc2(:,i);
    deltilde2 = glmfit1(X2(:,(p2+1):size(X2,2)),[d ones(size(d,1),1)],'binomial','logit','off',X2(:,1:p2)*b2,[ ] ,'off');
    deltatilde2 = [btildebc2(:,i);deltilde2];

    Htilde_bc2 = vc_logit(d,X2,[b2;deltilde2]);
    s2tilde_bc2(:,i) = diag(Htilde_bc2(1:p2,1:p2));

    biasalphatildebc2 = bias_alpha_logit(d,X2,[btildebc2(:,i);deltilde2],Dp);
    sigma2alphatildebc2 = sigma2_alpha_logit(d,X2,[btildebc2(:,i);deltilde2],Dp);
    phialphatildebc2 = phi_alpha_logit(d,X2,[btildebc2(:,i);deltilde2],Dp);
    mutildebc2 = x2p*btildebc2(:,i) + kron(deltilde2,ones(T,1));
    
    bias_meff_bc2_fs = bias_meff_logit(x2bar_fs(:,i), deltatilde2, biasalphatildebc2, sigma2alphatildebc2,p2,Dp,N);  
    mefftildebc2_fs(:,i) = btildebc2(:,i) * sum(logpdf(x2bar_fs(:,i)' * btildebc2(:,i) + deltatilde2((p2+1):size(deltatilde2,1),1)))/N - bias_meff_bc2_fs/T;
    bias_ameff_bc2_fs = bias_ameff_logit(mutildebc2, deltatilde2, biasalphatildebc2, sigma2alphatildebc2, phialphatildebc2, p2 ,Dp, N*T);
    amefftildebc2_fs(:,i) = btildebc2(:,i) * sum(logpdf(X2*deltatilde2))/(N*T) - bias_ameff_bc2_fs/T;
    Htilde_meff_bc2_fs = vc_meff_logit(d, x2bar_fs(:,i), deltatilde2, Htilde_bc2, s2x2bar_fs, N, p2);
    s2tilde_meff_bc2_fs(:,i) = diag(Htilde_meff_bc2_fs);
    Htilde_ameff_bc2_fs = vc_ameff_logit(d, X2, deltatilde2, Htilde_bc2, p2, N*T);
    s2tilde_ameff_bc2_fs(:,i) = diag(Htilde_ameff_bc2_fs);
    
% ANALYTICAL 2 BC MLE LOGIT;    
    BIAS3(:,i) = bias_beta_logit_mle2(d,X2,deltatilde,Np,Dp);
    btildebc3(:,i) = btilde1(:,i) - (1/T)*BIAS3(:,i);
    b3 = btildebc3(:,i);
    deltilde3 = glmfit1(X2(:,(p2+1):size(X2,2)),[d ones(size(d,1),1)],'binomial','logit','off',X2(:,1:p2)*b3,[ ] ,'off');
    deltatilde3 = [btildebc3(:,i);deltilde3];

    Htilde_bc3 = vc_logit(d,X2,[b3;deltilde3]);
    s2tilde_bc3(:,i) = diag(Htilde_bc3(1:p2,1:p2));

    biasalphatildebc3 = bias_alpha_logit_mle2(d,X2,[btildebc3(:,i);deltilde3],Dp);
    sigma2alphatildebc3 = sigma2_alpha_logit_mle2(d,X2,[btildebc3(:,i);deltilde3],Dp);
    phialphatildebc3 = phi_alpha_logit_mle2(d,X2,[btildebc3(:,i);deltilde3],Dp);
    mutildebc3 = x2p*btildebc3(:,i) + kron(deltilde3,ones(T,1));
    
    bias_meff_bc3_fs = bias_meff_logit(x2bar_fs(:,i), deltatilde3, biasalphatildebc3, sigma2alphatildebc3,p2,Dp,N);  
    mefftildebc3_fs(:,i) = btildebc3(:,i) * sum(logpdf(x2bar_fs(:,i)' * btildebc3(:,i) + deltatilde3((p2+1):size(deltatilde3,1),1)))/N - bias_meff_bc3_fs/T;
    bias_ameff_bc3_fs = bias_ameff_logit(mutildebc3, deltatilde3, biasalphatildebc3, sigma2alphatildebc3, phialphatildebc3, p2 ,Dp, N*T);
    amefftildebc3_fs(:,i) = btildebc3(:,i) * sum(logpdf(X2*deltatilde3))/(N*T) - bias_ameff_bc3_fs/T;
    Htilde_meff_bc3_fs = vc_meff_logit(d, x2bar_fs(:,i), deltatilde3, Htilde_bc3, s2x2bar_fs, N, p2);
    s2tilde_meff_bc3_fs(:,i) = diag(Htilde_meff_bc3_fs);
    Htilde_ameff_bc3_fs = vc_ameff_logit(d, X2, deltatilde3, Htilde_bc3, p2, N*T);
    s2tilde_ameff_bc3_fs(:,i) = diag(Htilde_ameff_bc3_fs);

% BC - CONDITIONAL LOGIT;
    btildebc4(:,i) = fminunc('clogit', btildebc1(:,i), options, d, x2p, Np, T);
    b4 = btildebc4(:,i);
    deltilde4 = glmfit1(X2(:,(p2+1):size(X2,2)),[d ones(size(d,1),1)],'binomial','logit','off',X2(:,1:p2)*b4,[ ] ,'off');
    deltatilde4 = [btildebc4(:,i);deltilde4];

    Htilde_bc4 = vc_logit(d,X2,[b4;deltilde4]);
    s2tilde_bc4(:,i) = diag(Htilde_bc4(1:p2,1:p2));

    biasalphatildebc4 = bias_alpha_logit_mle2(d,X2,[btildebc4(:,i);deltilde4],Dp);
    sigma2alphatildebc4 = sigma2_alpha_logit_mle2(d,X2,[btildebc4(:,i);deltilde4],Dp);
    phialphatildebc4 = phi_alpha_logit_mle2(d,X2,[btildebc4(:,i);deltilde4],Dp);
    mutildebc4 = x2p*btildebc4(:,i) + kron(deltilde4,ones(T,1));


    bias_meff_bc4_fs = bias_meff_logit(x2bar_fs(:,i), deltatilde4, biasalphatildebc4, sigma2alphatildebc4,p2,Dp,N);  
    mefftildebc4_fs(:,i) = btildebc4(:,i) * sum(logpdf(x2bar_fs(:,i)' * btildebc4(:,i) + deltatilde4((p2+1):size(deltatilde4,1),1)))/N - bias_meff_bc4_fs/T;
    bias_ameff_bc4_fs = bias_ameff_logit(mutildebc4, deltatilde4, biasalphatildebc4, sigma2alphatildebc4, phialphatildebc4, p2 ,Dp, N*T);
    amefftildebc4_fs(:,i) = btildebc4(:,i) * sum(logpdf(X2*deltatilde4))/(N*T) - bias_ameff_bc4_fs/T;
    Htilde_meff_bc4_fs = vc_meff_logit(d, x2bar_fs(:,i), deltatilde4, Htilde_bc4, s2x2bar_fs, N, p2);
    s2tilde_meff_bc4_fs(:,i) = diag(Htilde_meff_bc4_fs);
    Htilde_ameff_bc4_fs = vc_ameff_logit(d, X2, deltatilde4, Htilde_bc4, p2, N*T);
    s2tilde_ameff_bc4_fs(:,i) = diag(Htilde_ameff_bc4_fs);

    
% CONDITIONAL LOGIT (WITHOUT BC);


    mefftildebc5_fs(:,i) = btildebc4(:,i) * sum(logpdf(x2bar_fs(:,i)' * btildebc4(:,i) + deltatilde4((p2+1):size(deltatilde4,1),1)))/N ;
    amefftildebc5_fs(:,i) = btildebc4(:,i) * sum(logpdf(X2*deltatilde4))/(N*T) ;
    Htilde_meff_bc5_fs = vc_meff_logit(d, x2bar_fs(:,i), deltatilde4, Htilde_bc4, s2x2bar_fs, N, p2);
    s2tilde_meff_bc5_fs(:,i) = diag(Htilde_meff_bc4_fs);
    Htilde_ameff_bc5_fs = vc_ameff_logit(d, X2, deltatilde4, Htilde_bc4, p2, N*T);
    s2tilde_ameff_bc5_fs(:,i) = diag(Htilde_ameff_bc4_fs);


    
% JACKKNIFE;   

TIME = kron(ones(Np,1),[1:T]');
  
    for j = 1:T,
        I = find(TIME ~= j);
        wd = d(I);
        wx2 = x2p(I,:);
        wDp = Dp(I);
        wFE = FEp(I,:);
        wdelta = delta;
        for k = 1:Np,
            J = find(Dp(I) == k);
            if mean(wd(J)) == 1 | mean(wd(J)) == 0,
                wd(J) = NaN;
                wx2(J,:) = NaN;
                wFE(J,:) = NaN;
                wFE(:,k) = NaN;
            end
        end
        K = find(isnan(wd));
        wd(K) = [];
        wFE(K,:) = [];
        wx2(K,:) = [];
        K = find(isnan(wFE(1,:)'));
        wFE(:,K) = [];
        wX2 = [wx2,wFE];
        wDp(K) = [ ];
        wDp = recode(wDp);
        wx2bar = mean(wx2)';
%        wdelta(K+size(x2,2)) = [];
%        d = fminunc2('probit',wdelta,options,wd,wX2);

%%%%%%%%%%%%%%%%%;
% FIRST STAGE;
%%%%%%%%%%%%%%%%%;
    % PROBIT;
        djk = glmfit1(wX2,[wd ones(size(wd,1),1)],'binomial','probit','off',[ ],[ ] ,'off');
        bjack1(:,j) = djk(1:p2,1);
        meffhatjack1_fs(:,j) = bjack1(:,j) * sum(normpdf(wx2bar' * bjack1(:,j) + djk((p2+1):size(djk,1),1)))/N;
        ameffhatjack1_fs(:,j) = bjack1(:,j) * sum(normpdf(wX2*djk))/(N*(T-1));

    % LOGIT;
        djk2 = glmfit1(wX2,[wd ones(size(wd,1),1)],'binomial','logit','off',[ ],[ ] ,'off');
        bjack2(:,j) = djk2(1:p2,1);
        mefftildejack2_fs(:,j) = bjack2(:,j) * sum(logpdf(wx2bar' * bjack2(:,j) + djk2((p2+1):size(djk2,1),1)))/N;
        amefftildejack2_fs(:,j) = bjack2(:,j) * sum(logpdf(wX2*djk2))/(N*(T-1));

        
    end

    % PROBIT;    
    bhatjack1(:,i) = T*bhat1(:,i) - (T-1)*mean(bjack1,2);
    dhatjack1 = glmfit1(X2(:,(p2+1):size(X2,2)),[d ones(size(d,1),1)],'binomial','probit','off',X2(:,1:p2)*bhatjack1(:,i),[ ] ,'off');
    Hhat_jack = vc_probit(d,X2,[bhatjack1(:,i);dhatjack1]);
    s2hat_jack(:,i) = diag(Hhat_jack(1:p2,1:p2));


    deltajk = [bhatjack1(:,i);dhatjack1];

    meffhatjack_fs(:,i) = T*meffhat_fs(:,i) - (T-1)*mean(meffhatjack1_fs,2);
    ameffhatjack_fs(:,i) = T*ameffhat_fs(:,i) - (T-1)*mean(ameffhatjack1_fs,2);
    Hhat_meff_jack_fs = vc_meff_probit(d, x2bar_fs(:,i), deltajk, Hhat_jack, s2x2bar_fs, N, p2);
    s2hat_meff_jack_fs(:,i) = diag(Hhat_meff_jack_fs);
    Hhat_ameff_jack_fs = vc_ameff_probit(d, X2, deltajk, Hhat_jack, p2, N*T);
    s2hat_ameff_jack_fs(:,i) = diag(Hhat_ameff_jack_fs);

    
    % LOGIT;    
    btildejack(:,i) = T*btilde1(:,i) - (T-1)*mean(bjack2,2);
    dtildejack = glmfit1(X2(:,(p2+1):size(X2,2)),[d ones(size(d,1),1)],'binomial','logit','off',X2(:,1:p2)*btildejack(:,i),[ ] ,'off');
    Htilde_jack = vc_logit(d,X2,[btildejack(:,i);dtildejack]);
    s2tilde_jack(:,i) = diag(Htilde_jack(1:p2,1:p2));


    deltajk2 = [btildejack(:,i);dtildejack];

    mefftildejack_fs(:,i) = T*mefftilde_fs(:,i) - (T-1)*mean(mefftildejack2_fs,2);
    amefftildejack_fs(:,i) = T*amefftilde_fs(:,i) - (T-1)*mean(amefftildejack2_fs,2);
    Htilde_meff_jack_fs = vc_meff_logit(d, x2bar_fs(:,i), deltajk2, Htilde_jack, s2x2bar_fs, N, p2);
    s2tilde_meff_jack_fs(:,i) = diag(Htilde_meff_jack_fs);
    Htilde_ameff_jack_fs = vc_ameff_logit(d, X2, deltajk2, Htilde_jack, p2, N*T);
    s2tilde_ameff_jack_fs(:,i) = diag(Htilde_ameff_jack_fs);

  


    
% REPORTING IN EACH SIMULATION;    

    disp('Beta');
    cprob*[mean(bhat1,2)  mean(bhatbc1,2) mean(bhatbc2,2) mean(bhatbc3,2)  mean(bhatbc4,2) ]
    [mean(btilde1,2) mean(btildebc1,2) mean(btildebc2,2) mean(btildebc3,2)  mean(btildebc4,2) ]
    

    

end
toc,


% NORMALIZATION FOR THE LOGIT;

btilde1 = clog*btilde1;
btildejack = clog*btildejack;
btildebc1 = clog*btildebc1;
btildebc2 = clog*btildebc2;
btildebc3 = clog*btildebc3;
btildebc4 = clog*btildebc4;

s2tilde_mle = (clog^2)*s2tilde_mle;
s2tilde_jack = (clog^2)*s2tilde_jack;
s2tilde_bc1 = (clog^2)*s2tilde_bc1;
s2tilde_bc2 = (clog^2)*s2tilde_bc2;
s2tilde_bc3 = (clog^2)*s2tilde_bc3;
s2tilde_bc4 = (clog^2)*s2tilde_bc4;


disp(size(bhat1));


disp('Table 1a: Coefficients beta1');
full([mean(bhat1(1,:))      median(bhat1(1,:))        sqrt(s2hat_mle(1,:))  ;...
    mean(bhatjack1(1,:))      median(bhatjack1(1,:))      sqrt(s2hat_jack(1,:))  ;...
    mean(bhatbc1(1,:))      median(bhatbc1(1,:))      sqrt(s2hat_bc1(1,:))  ;...
    mean(bhatbc2(1,:))      median(bhatbc2(1,:))      sqrt(s2hat_bc2(1,:))  ;...
    mean(bhatbc3(1,:))      median(bhatbc3(1,:))      sqrt(s2hat_bc3(1,:))  ; ...
    mean(bhatbc4(1,:))      median(bhatbc4(1,:))      sqrt(s2hat_bc4(1,:))  ; ...
    mean(btilde1(1,:))      median(btilde1(1,:))      sqrt(s2tilde_mle(1,:)) ;...
    mean(btildejack(1,:))      median(btildejack(1,:))      sqrt(s2tilde_jack(1,:)) ;...
    mean(btildebc1(1,:))    median(btildebc1(1,:))    sqrt(s2tilde_bc1(1,:)) ;...
    mean(btildebc2(1,:))    median(btildebc2(1,:))    sqrt(s2tilde_bc2(1,:))  ;...
    mean(btildebc3(1,:))    median(btildebc3(1,:))    sqrt(s2tilde_bc3(1,:)) ;...
    mean(btildebc4(1,:))    median(btildebc4(1,:))    sqrt(s2tilde_bc4(1,:))])

disp('Table 1b: Coefficients beta2');
full([mean(bhat1(2,:))      median(bhat1(2,:))        sqrt(s2hat_mle(2,:))  ;...
    mean(bhatjack1(2,:))      median(bhatjack1(2,:))      sqrt(s2hat_jack(2,:))  ;...
    mean(bhatbc1(2,:))      median(bhatbc1(2,:))      sqrt(s2hat_bc1(2,:))  ;...
    mean(bhatbc2(2,:))      median(bhatbc2(2,:))      sqrt(s2hat_bc2(2,:))  ;...
    mean(bhatbc3(2,:))      median(bhatbc3(2,:))      sqrt(s2hat_bc3(2,:))  ; ...
    mean(bhatbc4(2,:))      median(bhatbc4(2,:))      sqrt(s2hat_bc4(2,:))  ; ...
    mean(btilde1(2,:))      median(btilde1(2,:))      sqrt(s2tilde_mle(2,:)) ;...
    mean(btildejack(2,:))      median(btildejack(2,:))      sqrt(s2tilde_jack(2,:)) ;...
    mean(btildebc1(2,:))    median(btildebc1(2,:))    sqrt(s2tilde_bc1(2,:)) ;...
    mean(btildebc2(2,:))    median(btildebc2(2,:))    sqrt(s2tilde_bc2(2,:))  ;...
    mean(btildebc3(2,:))    median(btildebc3(2,:))    sqrt(s2tilde_bc3(2,:)) ;...
    mean(btildebc4(2,:))    median(btildebc4(2,:))    sqrt(s2tilde_bc4(2,:))])

disp('Table 1b: Coefficients beta3');
full([mean(bhat1(3,:))      median(bhat1(3,:))        sqrt(s2hat_mle(3,:))  ;...
    mean(bhatjack1(3,:))      median(bhatjack1(3,:))      sqrt(s2hat_jack(3,:))  ;...
    mean(bhatbc1(3,:))      median(bhatbc1(3,:))      sqrt(s2hat_bc1(3,:))  ;...
    mean(bhatbc2(3,:))      median(bhatbc2(3,:))      sqrt(s2hat_bc2(3,:))  ;...
    mean(bhatbc3(3,:))      median(bhatbc3(3,:))      sqrt(s2hat_bc3(3,:))  ; ...
    mean(bhatbc4(3,:))      median(bhatbc4(3,:))      sqrt(s2hat_bc4(3,:))  ; ...
    mean(btilde1(3,:))      median(btilde1(3,:))      sqrt(s2tilde_mle(3,:)) ;...
    mean(btildejack(3,:))      median(btildejack(3,:))      sqrt(s2tilde_jack(3,:)) ;...
    mean(btildebc1(3,:))    median(btildebc1(3,:))    sqrt(s2tilde_bc1(3,:)) ;...
    mean(btildebc2(3,:))    median(btildebc2(3,:))    sqrt(s2tilde_bc2(3,:))  ;...
    mean(btildebc3(3,:))    median(btildebc3(3,:))    sqrt(s2tilde_bc3(3,:)) ;...
    mean(btildebc4(3,:))    median(btildebc4(3,:))    sqrt(s2tilde_bc4(3,:))])

disp('Table 1b: Coefficients beta4');
full([mean(bhat1(4,:))      median(bhat1(4,:))        sqrt(s2hat_mle(4,:))  ;...
    mean(bhatjack1(4,:))      median(bhatjack1(4,:))      sqrt(s2hat_jack(4,:))  ;...
    mean(bhatbc1(4,:))      median(bhatbc1(4,:))      sqrt(s2hat_bc1(4,:))  ;...
    mean(bhatbc2(4,:))      median(bhatbc2(4,:))      sqrt(s2hat_bc2(4,:))  ;...
    mean(bhatbc3(4,:))      median(bhatbc3(4,:))      sqrt(s2hat_bc3(4,:))  ; ...
    mean(bhatbc4(4,:))      median(bhatbc4(4,:))      sqrt(s2hat_bc4(4,:))  ; ...
    mean(btilde1(4,:))      median(btilde1(4,:))      sqrt(s2tilde_mle(4,:)) ;...
    mean(btildejack(4,:))      median(btildejack(4,:))      sqrt(s2tilde_jack(4,:)) ;...
    mean(btildebc1(4,:))    median(btildebc1(4,:))    sqrt(s2tilde_bc1(4,:)) ;...
    mean(btildebc2(4,:))    median(btildebc2(4,:))    sqrt(s2tilde_bc2(4,:))  ;...
    mean(btildebc3(4,:))    median(btildebc3(4,:))    sqrt(s2tilde_bc3(4,:)) ;...
    mean(btildebc4(4,:))    median(btildebc4(4,:))    sqrt(s2tilde_bc4(4,:))])

disp('Table 1b: Coefficients beta5');
full([mean(bhat1(5,:))      median(bhat1(5,:))        sqrt(s2hat_mle(5,:))  ;...
    mean(bhatjack1(5,:))      median(bhatjack1(5,:))      sqrt(s2hat_jack(5,:))  ;...
    mean(bhatbc1(5,:))      median(bhatbc1(5,:))      sqrt(s2hat_bc1(5,:))  ;...
    mean(bhatbc2(5,:))      median(bhatbc2(5,:))      sqrt(s2hat_bc2(5,:))  ;...
    mean(bhatbc3(5,:))      median(bhatbc3(5,:))      sqrt(s2hat_bc3(5,:))  ; ...
    mean(bhatbc4(5,:))      median(bhatbc4(5,:))      sqrt(s2hat_bc4(5,:))  ; ...
    mean(btilde1(5,:))      median(btilde1(5,:))      sqrt(s2tilde_mle(5,:)) ;...
    mean(btildejack(5,:))      median(btildejack(5,:))      sqrt(s2tilde_jack(5,:)) ;...
    mean(btildebc1(5,:))    median(btildebc1(5,:))    sqrt(s2tilde_bc1(5,:)) ;...
    mean(btildebc2(5,:))    median(btildebc2(5,:))    sqrt(s2tilde_bc2(5,:))  ;...
    mean(btildebc3(5,:))    median(btildebc3(5,:))    sqrt(s2tilde_bc3(5,:)) ;...
    mean(btildebc4(5,:))    median(btildebc4(5,:))    sqrt(s2tilde_bc4(5,:))])

disp('Table 1b: Coefficients beta6');
full([mean(bhat1(6,:))      median(bhat1(6,:))        sqrt(s2hat_mle(6,:))  ;...
    mean(bhatjack1(6,:))      median(bhatjack1(6,:))      sqrt(s2hat_jack(6,:))  ;...
    mean(bhatbc1(6,:))      median(bhatbc1(6,:))      sqrt(s2hat_bc1(6,:))  ;...
    mean(bhatbc2(6,:))      median(bhatbc2(6,:))      sqrt(s2hat_bc2(6,:))  ;...
    mean(bhatbc3(6,:))      median(bhatbc3(6,:))      sqrt(s2hat_bc3(6,:))  ; ...
    mean(bhatbc4(6,:))      median(bhatbc4(6,:))      sqrt(s2hat_bc4(6,:))  ; ...
    mean(btilde1(6,:))      median(btilde1(6,:))      sqrt(s2tilde_mle(6,:)) ;...
    mean(btildejack(6,:))      median(btildejack(6,:))      sqrt(s2tilde_jack(6,:)) ;...
    mean(btildebc1(6,:))    median(btildebc1(6,:))    sqrt(s2tilde_bc1(6,:)) ;...
    mean(btildebc2(6,:))    median(btildebc2(6,:))    sqrt(s2tilde_bc2(6,:))  ;...
    mean(btildebc3(6,:))    median(btildebc3(6,:))    sqrt(s2tilde_bc3(6,:)) ;...
    mean(btildebc4(6,:))    median(btildebc4(6,:))    sqrt(s2tilde_bc4(6,:))])



disp('Table 10b: Average Marginal Effects beta1 (FS)');
100*full([mean(ameffhat_fs(1,:))      sqrt(s2hat_ameff_mle_fs(1,:));...
    mean(ameffhatjack_fs(1,:))     sqrt(s2hat_ameff_jack_fs(1,:));...
    mean(ameffhatbc1_fs(1,:))     sqrt(s2hat_ameff_bc1_fs(1,:));...
    mean(ameffhatbc2_fs(1,:))     sqrt(s2hat_ameff_bc2_fs(1,:));...
    mean(ameffhatbc3_fs(1,:))     sqrt(s2hat_ameff_bc3_fs(1,:)); ...
    mean(ameffhatbc4_fs(1,:))     sqrt(s2hat_ameff_bc4_fs(1,:)); ...
    mean(amefftilde_fs(1,:))      sqrt(s2tilde_ameff_mle_fs(1,:));...
    mean(amefftildejack_fs(1,:))     sqrt(s2tilde_ameff_jack_fs(1,:));...
    mean(amefftildebc1_fs(1,:))   sqrt(s2tilde_ameff_bc1_fs(1,:));...
    mean(amefftildebc2_fs(1,:))   sqrt(s2tilde_ameff_bc2_fs(1,:));...
    mean(amefftildebc3_fs(1,:))   sqrt(s2tilde_ameff_bc3_fs(1,:)); ...
    mean(amefftildebc4_fs(1,:))   sqrt(s2tilde_ameff_bc4_fs(1,:)); ...
    mean(ameffhatolsen_fs(1,:))   sqrt(s2hat_ameff_olsen_fs(1,:));...
    mean(ameffhatlpm_fs(1,:)) sqrt(s2hat_ameff_lpm_fs(1,:)) ])

disp('Table 10b: Average Marginal Effects beta2 (FS)');
100*full([mean(ameffhat_fs(2,:))      sqrt(s2hat_ameff_mle_fs(2,:));...
    mean(ameffhatjack_fs(2,:))     sqrt(s2hat_ameff_jack_fs(2,:));...
    mean(ameffhatbc1_fs(2,:))     sqrt(s2hat_ameff_bc1_fs(2,:));...
    mean(ameffhatbc2_fs(2,:))     sqrt(s2hat_ameff_bc2_fs(2,:));...
    mean(ameffhatbc3_fs(2,:))     sqrt(s2hat_ameff_bc3_fs(2,:)); ...
    mean(ameffhatbc4_fs(2,:))     sqrt(s2hat_ameff_bc4_fs(2,:)); ...
    mean(amefftilde_fs(2,:))      sqrt(s2tilde_ameff_mle_fs(2,:));...
    mean(amefftildejack_fs(2,:))     sqrt(s2tilde_ameff_jack_fs(2,:));...
    mean(amefftildebc1_fs(2,:))   sqrt(s2tilde_ameff_bc1_fs(2,:));...
    mean(amefftildebc2_fs(2,:))   sqrt(s2tilde_ameff_bc2_fs(2,:));...
    mean(amefftildebc3_fs(2,:))   sqrt(s2tilde_ameff_bc3_fs(2,:)); ...
    mean(amefftildebc4_fs(2,:))   sqrt(s2tilde_ameff_bc4_fs(2,:)); ...
    mean(ameffhatolsen_fs(2,:))   sqrt(s2hat_ameff_olsen_fs(2,:));...
    mean(ameffhatlpm_fs(2,:)) sqrt(s2hat_ameff_lpm_fs(2,:)) ])

disp('Table 10b: Average Marginal Effects beta3 (FS)');
100*full([mean(ameffhat_fs(3,:))      sqrt(s2hat_ameff_mle_fs(3,:));...
    mean(ameffhatjack_fs(3,:))     sqrt(s2hat_ameff_jack_fs(3,:));...
    mean(ameffhatbc1_fs(3,:))     sqrt(s2hat_ameff_bc1_fs(3,:));...
    mean(ameffhatbc2_fs(3,:))     sqrt(s2hat_ameff_bc2_fs(3,:));...
    mean(ameffhatbc3_fs(3,:))     sqrt(s2hat_ameff_bc3_fs(3,:)); ...
    mean(ameffhatbc4_fs(3,:))     sqrt(s2hat_ameff_bc4_fs(3,:)); ...
    mean(amefftilde_fs(3,:))      sqrt(s2tilde_ameff_mle_fs(3,:));...
    mean(amefftildejack_fs(3,:))     sqrt(s2tilde_ameff_jack_fs(3,:));...
    mean(amefftildebc1_fs(3,:))   sqrt(s2tilde_ameff_bc1_fs(3,:));...
    mean(amefftildebc2_fs(3,:))   sqrt(s2tilde_ameff_bc2_fs(3,:));...
    mean(amefftildebc3_fs(3,:))   sqrt(s2tilde_ameff_bc3_fs(3,:)); ...
    mean(amefftildebc4_fs(3,:))   sqrt(s2tilde_ameff_bc4_fs(3,:)); ...
    mean(ameffhatolsen_fs(3,:))   sqrt(s2hat_ameff_olsen_fs(3,:));...
    mean(ameffhatlpm_fs(3,:)) sqrt(s2hat_ameff_lpm_fs(3,:)) ])


disp('Table 10b: Average Marginal Effects beta4 (FS)');
100*full([mean(ameffhat_fs(4,:))      sqrt(s2hat_ameff_mle_fs(4,:));...
    mean(ameffhatjack_fs(4,:))     sqrt(s2hat_ameff_jack_fs(4,:));...
    mean(ameffhatbc1_fs(4,:))     sqrt(s2hat_ameff_bc1_fs(4,:));...
    mean(ameffhatbc2_fs(4,:))     sqrt(s2hat_ameff_bc2_fs(4,:));...
    mean(ameffhatbc3_fs(4,:))     sqrt(s2hat_ameff_bc3_fs(4,:)); ...
    mean(ameffhatbc4_fs(4,:))     sqrt(s2hat_ameff_bc4_fs(4,:)); ...
    mean(amefftilde_fs(4,:))      sqrt(s2tilde_ameff_mle_fs(4,:));...
    mean(amefftildejack_fs(4,:))     sqrt(s2tilde_ameff_jack_fs(4,:));...
    mean(amefftildebc1_fs(4,:))   sqrt(s2tilde_ameff_bc1_fs(4,:));...
    mean(amefftildebc2_fs(4,:))   sqrt(s2tilde_ameff_bc2_fs(4,:));...
    mean(amefftildebc3_fs(4,:))   sqrt(s2tilde_ameff_bc3_fs(4,:)); ...
    mean(amefftildebc4_fs(4,:))   sqrt(s2tilde_ameff_bc4_fs(4,:)); ...
    mean(ameffhatolsen_fs(4,:))   sqrt(s2hat_ameff_olsen_fs(4,:));...
    mean(ameffhatlpm_fs(4,:)) sqrt(s2hat_ameff_lpm_fs(4,:)) ])

disp('Table 10b: Average Marginal Effects beta5 (FS)');
100*full([mean(ameffhat_fs(5,:))      sqrt(s2hat_ameff_mle_fs(5,:));...
    mean(ameffhatjack_fs(5,:))     sqrt(s2hat_ameff_jack_fs(5,:));...
    mean(ameffhatbc1_fs(5,:))     sqrt(s2hat_ameff_bc1_fs(5,:));...
    mean(ameffhatbc2_fs(5,:))     sqrt(s2hat_ameff_bc2_fs(5,:));...
    mean(ameffhatbc3_fs(5,:))     sqrt(s2hat_ameff_bc3_fs(5,:)); ...
    mean(ameffhatbc4_fs(5,:))     sqrt(s2hat_ameff_bc4_fs(5,:)); ...
    mean(amefftilde_fs(5,:))      sqrt(s2tilde_ameff_mle_fs(5,:));...
    mean(amefftildejack_fs(5,:))     sqrt(s2tilde_ameff_jack_fs(5,:));...
    mean(amefftildebc1_fs(5,:))   sqrt(s2tilde_ameff_bc1_fs(5,:));...
    mean(amefftildebc2_fs(5,:))   sqrt(s2tilde_ameff_bc2_fs(5,:));...
    mean(amefftildebc3_fs(5,:))   sqrt(s2tilde_ameff_bc3_fs(5,:)); ...
    mean(amefftildebc4_fs(5,:))   sqrt(s2tilde_ameff_bc4_fs(5,:)); ...
    mean(ameffhatolsen_fs(5,:))   sqrt(s2hat_ameff_olsen_fs(5,:));...
    mean(ameffhatlpm_fs(5,:)) sqrt(s2hat_ameff_lpm_fs(5,:)) ])

disp('Table 10b: Average Marginal Effects beta6 (FS)');
100*full([mean(ameffhat_fs(6,:))      sqrt(s2hat_ameff_mle_fs(6,:));...
    mean(ameffhatjack_fs(6,:))     sqrt(s2hat_ameff_jack_fs(6,:));...
    mean(ameffhatbc1_fs(6,:))     sqrt(s2hat_ameff_bc1_fs(6,:));...
    mean(ameffhatbc2_fs(6,:))     sqrt(s2hat_ameff_bc2_fs(6,:));...
    mean(ameffhatbc3_fs(6,:))     sqrt(s2hat_ameff_bc3_fs(6,:)); ...
    mean(ameffhatbc4_fs(6,:))     sqrt(s2hat_ameff_bc4_fs(6,:)); ...
    mean(amefftilde_fs(6,:))      sqrt(s2tilde_ameff_mle_fs(6,:));...
    mean(amefftildejack_fs(6,:))     sqrt(s2tilde_ameff_jack_fs(6,:));...
    mean(amefftildebc1_fs(6,:))   sqrt(s2tilde_ameff_bc1_fs(6,:));...
    mean(amefftildebc2_fs(6,:))   sqrt(s2tilde_ameff_bc2_fs(6,:));...
    mean(amefftildebc3_fs(6,:))   sqrt(s2tilde_ameff_bc3_fs(6,:)); ...
    mean(amefftildebc4_fs(6,:))   sqrt(s2tilde_ameff_bc4_fs(6,:)); ...
    mean(ameffhatolsen_fs(6,:))   sqrt(s2hat_ameff_olsen_fs(6,:));...
    mean(ameffhatlpm_fs(6,:)) sqrt(s2hat_ameff_lpm_fs(6,:)) ])

% Average effect of Age;   

ameffhat_fs_age = sum((bhat1(5,i) + 2*bhat1(6,i)*X2(:,5)).*normpdf(X2*deltahat))/(N*T);
Hhat_ameff_mle_fs_age = vc_ameff_probit_age(d, X2, deltahat, Hhat_mle, p2, N*T);
bias_ameff_bc3_fs_age = bias_ameff_probit_age(muhatbc3, deltahat3, biasalphahatbc3, sigma2alphahatbc3, phialphahatbc3, p2 ,Dp, N*T,X2);
ameffhatbc3_fs_age = sum((bhatbc3(5,i) + 2*bhatbc3(6,i)*X2(:,5)).*normpdf(X2*deltahat3))/(N*T) - bias_ameff_bc3_fs_age/T;
Hhat_ameff_bc3_fs_age = vc_ameff_probit_age(d, X2, deltahat3, Hhat_bc3, p2, N*T);



save z:\Marginal_effects\Applications\LFP3\results\static\specification3
    

